@@ -249,42 +249,19 @@ static CalcPlugin *calc_new(XfcePanelPlugin *plugin)
 
     gtk_entry_set_max_length(GTK_ENTRY(entry), 50);
     gtk_entry_set_width_chars(GTK_ENTRY(entry), calc->size);
-#if GTK_CHECK_VERSION (3, 22, 20)
     gtk_entry_set_input_hints (GTK_ENTRY(entry), GTK_INPUT_HINT_NO_EMOJI);
-#endif
 
     return calc;
 }
 
 
-/* Used with g_list_foreach() to free data items in a list. */
-
-static void free_stuff(gpointer data, gpointer unused)
-{
-    g_free(data);
-}
-
-
 static void calc_free(XfcePanelPlugin *plugin, CalcPlugin *calc)
 {
-    GtkWidget *dialog;
-
-    dialog = g_object_get_data(G_OBJECT(plugin), "dialog");
+    GtkWidget *dialog = g_object_get_data(G_OBJECT(plugin), "dialog");
     if (dialog != NULL)
         gtk_widget_destroy(dialog);
 
-    gtk_widget_destroy(calc->ebox);
-    gtk_widget_destroy(calc->box);
-    gtk_widget_destroy(calc->combo);
-
-    g_list_foreach(calc->expr_hist, (GFunc)free_stuff, NULL);
-    g_list_free(calc->expr_hist);
-
-    /* 
-     * FIXME: Do we need to free the strings in the combo list, or is the
-     * freeing of expr_hist enough?
-     */
-
+    g_list_free_full(calc->expr_hist, g_free);
     g_slice_free(CalcPlugin, calc);
 }
 
@@ -412,18 +389,17 @@ static void calc_configure(XfcePanelPlugin *plugin, CalcPlugin *calc)
     GtkWidget *size_label;
     GtkWidget *size_spin;
     GtkWidget *button;
-    GtkWidget *image;
     GtkAdjustment *adjustment;
 
     xfce_panel_plugin_block_menu(plugin);
 
     toplevel = gtk_widget_get_toplevel(GTK_WIDGET(plugin)); 
-    dialog = xfce_titled_dialog_new_with_buttons(_("Calculator Plugin"),
+    dialog = xfce_titled_dialog_new_with_mixed_buttons(_("Calculator Plugin"),
                        GTK_WINDOW(toplevel),
                        GTK_DIALOG_DESTROY_WITH_PARENT,
-                       _("_Close"), GTK_RESPONSE_OK, NULL);
+                       "window-close-symbolic", _("_Close"), GTK_RESPONSE_OK, NULL);
 
-#if LIBXFCE4UI_CHECK_VERSION (4, 15, 1)
+#if !LIBXFCE4UI_CHECK_VERSION (4, 19, 3)
   xfce_titled_dialog_create_action_area (XFCE_TITLED_DIALOG (dialog));
 #endif
 
@@ -497,17 +473,6 @@ static void calc_configure(XfcePanelPlugin *plugin, CalcPlugin *calc)
     g_signal_connect(button, "toggled",
                      G_CALLBACK(calc_move_cursor_changed), calc);
 
-    /* add the "Close" button */
-    button = gtk_button_new_with_mnemonic (_("_Close"));
-    image = gtk_image_new_from_icon_name ("window-close", GTK_ICON_SIZE_BUTTON);
-    gtk_button_set_image (GTK_BUTTON (button), image);
-#if LIBXFCE4UI_CHECK_VERSION (4, 15, 1)
-    xfce_titled_dialog_add_action_widget (XFCE_TITLED_DIALOG (dialog), button, GTK_RESPONSE_OK);
-#else
-    gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_OK);
-#endif
-    gtk_widget_show (button);
-
     gtk_widget_show(dialog);
 }
 
@@ -524,7 +489,7 @@ static void calc_about (XfcePanelPlugin *plugin)
       "program-name", PACKAGE_NAME,
       "comments", _("Calculator for Xfce panel"),
       "website", "https://docs.xfce.org/panel-plugins/xfce4-calculator-plugin",
-      "copyright", "Copyright \302\251 2003-2023 The Xfce development team",
+      "copyright", "Copyright \302\251 2003-2024 The Xfce development team",
       "authors", authors, NULL);
 }
 
